@@ -3,62 +3,7 @@ import os
 import requests
 import json
 import argparse
-
-# create cli argument for filepath
-parser = argparse.ArgumentParser(description='Scan a CFT Template')
-parser.add_argument("--scan", 
-                    choices=["all", "fail", "extreme", "veryhigh", "high", "medium", "low"],
-                    required=True, type=str, help="Filter your Scan by Severity")
-parser.add_argument(dest="cloudformationtemp", help="specify file path")
-args = parser.parse_args()
-
-cloudformationtemp = args.cloudformationtemp
-scan = args.scan
-
-# set Environment variable. 
-api= os.environ.get('apiKey')
-# Region in which Cloud Conformity serves your organisation
-region="us-west-2"
-#API connection for CC
-endpoint = 'https://' + region + '-api.cloudconformity.com'
-url = endpoint + '/v1/template-scanner/scan'
-url2 = endpoint + '/v1/services'
-
-headers = {
-	'Content-Type': 'application/vnd.api+json',
-	'Authorization': 'ApiKey ' + api
-}
-
-#open file and print contents.
-try:
-    contents = open(cloudformationtemp, 'r').read() 
-except ValueError:
-    print("Template Scanner could not process your template...")
-    sys.exit()
-
-payload =  {
-	'data': {
-		'attributes': {
-			'type': 'cloudformation-template',
-			'contents': contents
-		}
-	}
-}
-# post method
-resp = requests.post(url, headers=headers, data=json.dumps(payload))
-TurnResponsetoString = json.dumps(resp.json(), indent=2, sort_keys=True)
-formResponse = json.loads(TurnResponsetoString)
-# get method
-response = requests.get(url2,headers=headers)
-formatResponse = json.dumps(response.json(), indent=3, sort_keys=False)
-results = json.loads(formatResponse)
-
-# key for post call
-access = formResponse['data']
-# keys for get call
-access2 = results['data']
-access3 = results['included']
-def optionA():
+def optionA(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -89,7 +34,7 @@ def optionA():
                                     #print(ruleid)
                                     print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-def optionB():
+def optionB(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -120,7 +65,7 @@ def optionB():
                                         test = ( "https://www.cloudconformity.com/knowledge-base/" + provider + "/" + awsservice + "/" + html + ".html")
                                         #print(ruleid)
                                         print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
-def optionC():
+def optionC(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -153,7 +98,7 @@ def optionC():
                                             #print(ruleid)
                                             print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-def optionD():
+def optionD(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -186,7 +131,7 @@ def optionD():
                                             #print(ruleid)
                                             print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-def optionE():
+def optionE(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -219,7 +164,7 @@ def optionE():
                                             #print(ruleid)
                                             print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-def optionF():
+def optionF(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -252,7 +197,7 @@ def optionF():
                                             #print(ruleid)
                                             print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-def optionG():
+def optionG(access,access2,access3):
     for data in access:
         rules = data['relationships']
         ruledata = rules['rule']
@@ -285,22 +230,78 @@ def optionG():
                                             #print(ruleid)
                                             print("\n", aruleid, "\n", rulename,"\n", category,"\n", message,"\n", risk,"\n", info, "\n", test)
 
-if scan == "all":
-    optionA()
-elif scan == "fail":
-  optionB()
-elif scan == "extreme":
-      optionC()
-elif scan == "veryhigh":
-      optionD()
-elif scan == "high":
-      optionE()
-elif scan == "medium":
-      optionF()
-elif scan == "low":
-      optionF()
-else:
-    print("Not a correct filter option")
+def main():
+    # create cli argument for filepath
+    parser = argparse.ArgumentParser(description='Scan a CFT Template')
+    parser.add_argument("--scan", 
+                        choices=["all", "fail", "extreme", "veryhigh", "high", "medium", "low"],
+                        required=True, type=str, help="Filter your Scan by Severity")
+    parser.add_argument(dest="cloudformationtemp", help="specify file path")
+    args = parser.parse_args()
 
+    cloudformationtemp = args.cloudformationtemp
+    scan = args.scan
 
-    					
\ No newline at end of file
+    # set Environment variable. 
+    api= os.environ.get('apiKey')
+    # Region in which Cloud Conformity serves your organisation
+    region="us-west-2"
+    #API connection for CC
+    endpoint = 'https://' + region + '-api.cloudconformity.com'
+    url = endpoint + '/v1/template-scanner/scan'
+    url2 = endpoint + '/v1/services'
+
+    headers = {
+        'Content-Type': 'application/vnd.api+json',
+        'Authorization': 'ApiKey ' + api
+    }
+
+    #open file and print contents.
+    try:
+        contents = open(cloudformationtemp, 'r').read() 
+    except ValueError:
+        print("Template Scanner could not process your template...")
+        sys.exit()
+
+    payload =  {
+        'data': {
+            'attributes': {
+                'type': 'cloudformation-template',
+                'contents': contents
+            }
+        }
+    }
+    # post method
+    resp = requests.post(url, headers=headers, data=json.dumps(payload))
+    TurnResponsetoString = json.dumps(resp.json(), indent=2, sort_keys=True)
+    formResponse = json.loads(TurnResponsetoString)
+    # get method
+    response = requests.get(url2,headers=headers)
+    formatResponse = json.dumps(response.json(), indent=3, sort_keys=False)
+    results = json.loads(formatResponse)
+
+    # key for post call
+    access = formResponse['data']
+    # keys for get call
+    access2 = results['data']
+    access3 = results['included']
+
+    if scan == "all":
+        optionA(access,access2,access3)
+    elif scan == "fail":
+        optionB(access,access2,access3)
+    elif scan == "extreme":
+        optionC(access,access2,access3)
+    elif scan == "veryhigh":
+        optionD(access,access2,access3)
+    elif scan == "high":
+        optionE(access,access2,access3)
+    elif scan == "medium":
+        optionF(access,access2,access3)
+    elif scan == "low":
+        optionF(access,access2,access3)
+    else:
+        print("Not a correct filter option")
+
+if __name__ =="__main__":
+    main()
\ No newline at end of file
